@@ -40,14 +40,17 @@
 #'@note If High-Low prices are given, the function calculates the max/min using
 #'the high/low prices.  Otherwise the function calculates the max/min of the
 #'single series.
+#'@section Warning: The last value of the ZigZag indicator is unstable (i.e.
+#'unknown) until the turning point actually occurs. Therefore this indicator
+#'isn't well-suited for use for systematic trading strategies.
 #'@author Joshua Ulrich
 #'@references The following site(s) were used to code/document this
 #'indicator:\cr
 #'\url{http://www.fmlabs.com/reference/default.htm?url=ZigZag.htm}\cr
-#'\url{http://www.linnsoft.com/tour/techind/zigzag.htm}\cr
-#'\url{http://www.linnsoft.com/tour/techind/zigosc.htm}\cr
-#'\url{http://www.equis.com/Customer/Resources/TAAZ/?c=3&p=127}\cr
-#'\url{http://stockcharts.com/school/doku.php?id=chart_school:technical_indicators:zigzag}\cr
+#'\url{https://www.linnsoft.com/techind/zig-zag-indicator-zig-zzo}\cr
+#'\url{https://www.linnsoft.com/techind/zig-zag-oscillator-indicator-zzo}\cr
+#'\url{http://www.metastock.com/Customer/Resources/TAAZ/#127}\cr
+#'\url{http://www.stockcharts.com/school/doku.php?id=chart_school:technical_indicators:zigzag}\cr
 #'@keywords ts
 #'@examples
 #'
@@ -55,7 +58,6 @@
 #' data(ttrc)
 #' zz <- ZigZag( ttrc[,c("High", "Low")], change=20 )
 #'
-#'@export
 "ZigZag" <- 
 function( HL, change=10, percent=TRUE, retrace=FALSE, lastExtreme=TRUE ) {
 
@@ -79,28 +81,13 @@ function( HL, change=10, percent=TRUE, retrace=FALSE, lastExtreme=TRUE ) {
 
   stop("Price series must be either High-Low, or Univariate")
   
-  # Initialize necessary parameters
-  nn <- NROW(HL.na$nonNA)
-  zz <- rep(0, nn)
-  if(percent) {
-    change <- change/100
-  }
-
-  # Call Fortran routine
-  zz <- .Fortran("zigzag", iha = as.double( high ),
-                           ila = as.double( low ),
-                           la  = as.integer( nn ),
-                           ch  = as.double( change ),
-                           pct = as.integer( percent ),
-                           rtr = as.integer( retrace ),
-                           lex = as.integer( lastExtreme ),
-                           zz  = as.double( zz ),
-                           PACKAGE = "TTR",
-                           DUP = TRUE )$zz
+  # Call C routine
+  zz <- .Call("ttr_zigzag", as.numeric(high), as.numeric(low),
+              as.numeric(change), as.logical(percent), as.logical(retrace),
+              as.logical(lastExtreme), PACKAGE = "TTR")
   
   # Interpolate results
-  zz <- ifelse( zz==0, NA, zz )
-  zz <- approx( zz, xout=1:nn )$y
+  zz <- na.approx(zz, na.rm = FALSE)
 
   # Prepend NAs from original data
   zz <- c( rep( NA, HL.na$NAs ), zz ) 
